@@ -76,6 +76,9 @@ void MatWiz::set_properties()
 #else
   button_2->SetDefault();
 #endif
+  
+  m_inputs[0]->SetFocus();
+  m_inputs[0]->SetSelection(-1, -1);
 }
 
 void MatWiz::do_layout()
@@ -121,7 +124,7 @@ wxString MatWiz::GetValue()
   wxString cmd = wxT("matrix(");
   for (int i = 0; i < m_height; i++)
   {
-    cmd += wxT("[");
+    cmd += wxT("\n [");
     for (int j = 0; j < m_width; j++)
     {
 
@@ -140,10 +143,10 @@ wxString MatWiz::GetValue()
     if (i < m_height - 1)
       cmd += wxT(", ");
   }
-  if (m_width > 10 || m_height > 10)
-    cmd += wxT(")$");
+  if (m_width > 7 || m_height > 7)
+    cmd += wxT("\n)$");
   else
-    cmd += wxT(");");
+    cmd += wxT("\n);");
   return cmd;
 }
 
@@ -194,6 +197,8 @@ void MatDim::set_properties()
 #endif
 
   combo_box_1->SetSelection(0);
+  text_ctrl_1->SetFocus();
+  text_ctrl_1->SetSelection(-1, -1);
 }
 
 
