@@ -69,11 +69,12 @@ Plot3DWiz::Plot3DWiz(wxWindow* parent, int id,
   const wxString combo_box_1_choices[] =
     {
       _("default"),
+      _("inline"),
       wxT("gnuplot"),
       wxT("openmath")
     };
   combo_box_1 = new wxComboBox(this, -1, wxEmptyString, wxDefaultPosition,
-                               wxSize(150, -1), 3, combo_box_1_choices,
+                               wxSize(150, -1), 4, combo_box_1_choices,
                                wxCB_DROPDOWN);
   label_12 = new wxStaticText(this, -1, _("Options:"));
   const wxString combo_box_2_choices[] =
@@ -88,7 +89,7 @@ Plot3DWiz::Plot3DWiz(wxWindow* parent, int id,
   combo_box_2 = new wxComboBox(this, combobox, wxEmptyString, wxDefaultPosition,
                                wxSize(250, -1), 6, combo_box_2_choices,
                                wxCB_DROPDOWN);
-  check_box_1 = new wxCheckBox(this, -1, _("pm3d"));
+  check_box_1 = new wxCheckBox(this, -1, _("&pm3d"));
   label_13 = new wxStaticText(this, -1, _("Plot to file:"));
   text_ctrl_10 = new BTextCtrl(this, -1, wxEmptyString, wxDefaultPosition,
                                wxSize(250, -1));
@@ -123,13 +124,23 @@ void Plot3DWiz::set_properties()
   text_ctrl_9->SetValue(wxT("30"));
 
   button_3->SetToolTip(_("Browse"));
-  combo_box_1->SetSelection(0);
+  
+  bool pm3dValue = false;
 #if defined __WXMSW__
   button_1->SetDefault();
-  check_box_1->SetValue(true);
+  pm3dValue = true;
 #else
   button_2->SetDefault();
 #endif
+  
+  int selection = 1;
+  wxConfig::Get()->Read(wxT("Wiz/Plot3D/format"), &selection);
+  wxConfig::Get()->Read(wxT("Wiz/Plot3D/pm3d"), &pm3dValue);
+  
+  combo_box_1->SetSelection(selection);
+  check_box_1->SetValue(pm3dValue);
+  
+  text_ctrl_1->SetFocus();
 }
 
 
@@ -191,8 +202,15 @@ void Plot3DWiz::SetValue(wxString s)
 {
   if (s.StartsWith(wxT("plot3d")))
     Parse(s);
+  else if (s.StartsWith(wxT("wxplot3d")))
+  {
+    Parse(s.SubString(2, s.Length()));
+    combo_box_1->SetValue(_("inline"));
+  }
   else
     text_ctrl_1->SetValue(s);
+  
+  text_ctrl_1->SetSelection(-1, -1);
 }
 
 void Plot3DWiz::Parse(wxString s)
@@ -370,11 +388,11 @@ wxString Plot3DWiz::GetValue()
   s += wxT(",") + text_ctrl_6->GetValue();
   s += wxT(",") + text_ctrl_7->GetValue();
   s += wxT("]");
-  if (f != _("default"))
+  if (f != _("default") && f != _("inline"))
     s += wxT(", [plot_format,") + f + wxT("]");
   if (xg != 30 || yg != 30)
   {
-    s += wxT(", [grid,");
+    s += wxT(",\n [grid,");
     s += wxString::Format(wxT("%d"), xg);
     s += wxT(",");
     s += wxString::Format(wxT("%d"), yg);
@@ -382,27 +400,35 @@ wxString Plot3DWiz::GetValue()
   }
 #if defined (__WXMSW__)
   if (!check_box_1->IsChecked())
-    s += wxT(", [gnuplot_pm3d,false]");
+    s += wxT(",\n [gnuplot_pm3d,false]");
 #else
   if (check_box_1->IsChecked())
-    s += wxT(", [gnuplot_pm3d,true]");
+    s += wxT(",\n [gnuplot_pm3d,true]");
 #endif
 
   if (p.Length() > 0)
-    s += wxT(", [gnuplot_preamble, \"") + p + wxT("\"]");
+    s += wxT(",\n [gnuplot_preamble, \"") + p + wxT("\"]");
   if (file.Length())
   {
-    s += wxT(", [gnuplot_term, ps]");
+    s += wxT(",\n [gnuplot_term, ps]");
 #if defined (__WXMSW__)
     file.Replace(wxT("\\"), wxT("/"));
 #endif
 
     if (file.Right(4) != wxT(".eps") && file.Right(3) != wxT(".ps"))
       file = file + wxT(".eps");
-    s += wxT(", [gnuplot_out_file, \"") + file + wxT("\"]");
+    s += wxT(",\n [gnuplot_out_file, \"") + file + wxT("\"]");
   }
-  s += wxT(")$");
+  else if (f == _("inline"))
+    s = wxT("wx") + s;
+  
+  if (file.Length() == 0 && f == _("inline"))
+    s += wxT(");");
+  else
+    s += wxT(")$");
 
+  wxConfig::Get()->Write(wxT("Wiz/Plot3D/format"), combo_box_1->GetSelection());
+  wxConfig::Get()->Write(wxT("Wiz/Plot3D/pm3d"), check_box_1->GetValue());
   return s;
 }
 
