@@ -18,19 +18,20 @@
 ///
 
 #include "TextCell.h"
+#include "Setup.h"
+
+wxString g_foldText(_(" << Unfold >>"));
 
 TextCell::TextCell() : MathCell()
 {
   m_text = wxEmptyString;
   m_fontSize = -1;
-  m_textStyle = TS_NORMAL_TEXT;
   m_highlight = false;
 }
 
 TextCell::TextCell(wxString text) : MathCell()
 {
   m_text = text;
-  m_textStyle = TS_NORMAL_TEXT;
   m_text.Replace(wxT("\n"), wxEmptyString);
   m_highlight = false;
 }
@@ -78,11 +79,14 @@ void TextCell::RecalculateWidths(CellParser& parser, int fontsize, bool all)
     double scale = parser.GetScale();
     SetFont(parser, fontsize);
 
-    if (m_textStyle == TS_SPECIAL_CONSTANT && parser.HaveSymbolFont() && m_text == wxT("%pi"))
+    if (m_textStyle == TS_SPECIAL_CONSTANT && parser.HaveGreekFont() && m_text == wxT("%pi"))
       dc.GetTextExtent(GetGreekString(parser), &m_width, &m_height);
-    else if (m_textStyle == TS_SPECIAL_CONSTANT && parser.HaveSymbolFont() && m_text == wxT("inf"))
+#if defined __WXMSW__ || (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
+    else if (m_text == wxT("inf") || m_text == wxT("->") ||
+             m_text == wxT(">=") || m_text == wxT("<="))
       dc.GetTextExtent(GetSymbolString(parser), &m_width, &m_height);
-    else if (m_textStyle == TS_GREEK_CONSTANT && parser.HaveSymbolFont())
+#endif
+    else if (m_textStyle == TS_GREEK_CONSTANT && parser.HaveGreekFont())
       dc.GetTextExtent(GetGreekString(parser), &m_width, &m_height);
     else if (m_text == wxEmptyString)
     {
@@ -91,9 +95,9 @@ void TextCell::RecalculateWidths(CellParser& parser, int fontsize, bool all)
     }
     else
       dc.GetTextExtent(m_text, &m_width, &m_height);
-
-    m_width = m_width + 2 * SCALE_PX(2, scale);
-    m_height = m_height + 2 * SCALE_PX(2, scale);
+    
+    m_width = m_width + 2 * SCALE_PX(MC_TEXT_PADDING, scale);
+    m_height = m_height + 2 * SCALE_PX(MC_TEXT_PADDING, scale);
 
     if (m_isHidden)
     {
@@ -101,7 +105,12 @@ void TextCell::RecalculateWidths(CellParser& parser, int fontsize, bool all)
       m_width = -2 * MC_CELL_SKIP;
     }
 
-    m_center = m_height / 2;
+    m_realCenter = m_center = m_height / 2;
+    if (m_type == MC_TYPE_MAIN_PROMPT && !m_text.StartsWith(wxT("/*")))
+    {
+      m_center += m_height;
+      m_height += m_height;
+    }
   }
   MathCell::RecalculateWidths(parser, fontsize, all);
 }
@@ -124,22 +133,25 @@ void TextCell::Draw(CellParser& parser, wxPoint point, int fontsize, bool all)
     SetFont(parser, fontsize);
     SetForeground(parser);
 
-    if (m_textStyle == TS_SPECIAL_CONSTANT && parser.HaveSymbolFont() && m_text == wxT("%pi"))
+    if (m_textStyle == TS_SPECIAL_CONSTANT && parser.HaveGreekFont() && m_text == wxT("%pi"))
       dc.DrawText(GetGreekString(parser),
-                  point.x + SCALE_PX(2, scale),
-                  point.y - m_center + SCALE_PX(2, scale));
-    else if (m_textStyle == TS_SPECIAL_CONSTANT && parser.HaveSymbolFont() && m_text == wxT("inf"))
+                  point.x + SCALE_PX(MC_TEXT_PADDING, scale),
+                  point.y - m_realCenter + SCALE_PX(MC_TEXT_PADDING, scale));
+#if defined __WXMSW__ || (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
+    else if (m_text == wxT("inf") || m_text == wxT("->") ||
+             m_text == wxT(">=") || m_text == wxT("<="))
       dc.DrawText(GetSymbolString(parser),
-                  point.x + SCALE_PX(2, scale),
-                  point.y - m_center + SCALE_PX(2, scale));
-    else if (m_textStyle == TS_GREEK_CONSTANT && parser.HaveSymbolFont())
+                  point.x + SCALE_PX(MC_TEXT_PADDING, scale),
+                  point.y - m_realCenter + SCALE_PX(MC_TEXT_PADDING, scale));
+#endif
+    else if (m_textStyle == TS_GREEK_CONSTANT && parser.HaveGreekFont())
       dc.DrawText(GetGreekString(parser),
-                  point.x + SCALE_PX(2, scale),
-                  point.y - m_center + SCALE_PX(2, scale));
+                  point.x + SCALE_PX(MC_TEXT_PADDING, scale),
+                  point.y - m_realCenter + SCALE_PX(MC_TEXT_PADDING, scale));
     else
       dc.DrawText(m_text,
-                  point.x + SCALE_PX(2, scale),
-                  point.y - m_center + SCALE_PX(2, scale));
+                  point.x + SCALE_PX(MC_TEXT_PADDING, scale),
+                  point.y - m_realCenter + SCALE_PX(MC_TEXT_PADDING, scale));
   }
   MathCell::Draw(parser, point, fontsize, all);
 }
@@ -163,7 +175,7 @@ void TextCell::SetFont(CellParser& parser, int fontsize)
   switch(m_textStyle)
   {
   case TS_SPECIAL_CONSTANT:
-    if (parser.HaveSymbolFont() && m_text == wxT("%pi"))
+    if (parser.HaveGreekFont() && m_text == wxT("%pi"))
       dc.SetFont(wxFont(fontsize1 + parser.GetGreekFontAdj(),
                         wxMODERN,
                         parser.IsItalic(TS_GREEK_CONSTANT),
@@ -171,12 +183,14 @@ void TextCell::SetFont(CellParser& parser, int fontsize)
                         parser.IsUnderlined(TS_GREEK_CONSTANT),
                         parser.GetGreekFontName(),
                         parser.GetGreekFontEncoding()));
-    else if (parser.HaveSymbolFont() && m_text == wxT("inf"))
+#if defined __WXMSW__ || (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
+    else if (m_text == wxT("inf"))
       dc.SetFont(wxFont(fontsize1, wxMODERN,
                         parser.IsItalic(TS_NORMAL_TEXT),
                         parser.IsBold(TS_NORMAL_TEXT),
                         parser.IsUnderlined(TS_NORMAL_TEXT),
                         parser.GetSymbolFontName()));
+#endif
     else
       dc.SetFont(wxFont(fontsize1, wxMODERN,
                         parser.IsItalic(TS_SPECIAL_CONSTANT),
@@ -186,7 +200,7 @@ void TextCell::SetFont(CellParser& parser, int fontsize)
                         parser.GetFontEncoding()));
     break;
   case TS_GREEK_CONSTANT:
-    if (parser.HaveSymbolFont())
+    if (parser.HaveGreekFont())
       dc.SetFont(wxFont(fontsize1 + parser.GetGreekFontAdj(),
                         wxMODERN,
                         parser.IsItalic(TS_GREEK_CONSTANT),
@@ -230,6 +244,16 @@ void TextCell::SetFont(CellParser& parser, int fontsize)
                         parser.GetFontEncoding()));
       break;
     default:
+#if defined __WXMSW__ || (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
+    if (m_text == wxT("->") ||
+        m_text == wxT(">=") || m_text == wxT("<="))
+      dc.SetFont(wxFont(fontsize1, wxMODERN,
+                        parser.IsItalic(TS_NORMAL_TEXT),
+                        parser.IsBold(TS_NORMAL_TEXT),
+                        parser.IsUnderlined(TS_NORMAL_TEXT),
+                        parser.GetSymbolFontName()));
+    else
+#endif
       dc.SetFont(wxFont(fontsize1, wxMODERN,
                         parser.IsItalic(m_textStyle),
                         parser.IsBold(m_textStyle),
@@ -240,33 +264,6 @@ void TextCell::SetFont(CellParser& parser, int fontsize)
   }
 }
 
-void TextCell::SetForeground(CellParser& parser)
-{
-  wxDC& dc = parser.GetDC();
-  if (m_highlight)
-  {
-    dc.SetTextForeground(wxTheColourDatabase->Find(parser.GetColor(TS_HIGHLIGHT)));
-    return ;
-  }
-  switch (m_type)
-  {
-  case MC_TYPE_PROMPT:
-    dc.SetTextForeground(wxTheColourDatabase->Find(parser.GetColor(TS_OTHER_PROMPT)));
-    break;
-  case MC_TYPE_MAIN_PROMPT:
-    dc.SetTextForeground(wxTheColourDatabase->Find(parser.GetColor(TS_MAIN_PROMPT)));
-    break;
-  case MC_TYPE_ERROR:
-    dc.SetTextForeground(wxTheColourDatabase->Find(wxT("red")));
-    break;
-  case MC_TYPE_LABEL:
-    dc.SetTextForeground(wxTheColourDatabase->Find(parser.GetColor(TS_LABEL)));
-    break;
-  default:
-    dc.SetTextForeground(wxTheColourDatabase->Find(parser.GetColor(m_textStyle)));
-    break;
-  }
-}
 bool TextCell::IsOperator()
 {
   if (wxString(wxT("+*/-")).Find(m_text) >= 0)
@@ -280,6 +277,46 @@ wxString TextCell::ToString(bool all)
   return text + MathCell::ToString(all);
 }
 
+wxString TextCell::ToTeX(bool all)
+{
+  wxString text;
+  if (m_isHidden)
+    text = wxT("\\,");
+  else if (m_textStyle == TS_GREEK_CONSTANT)
+  {
+    text = m_text;
+    text.Replace(wxT("%"), wxT("\\"));
+  }
+  else if (m_textStyle == TS_SPECIAL_CONSTANT)
+  {
+    if (m_text == wxT("inf"))
+      text = wxT("\\infty ");
+    else if (m_text == wxT("%e"))
+      text = wxT("e");
+    else if (m_text == wxT("%i"))
+      text = wxT("i");
+    else if (m_text == wxT("%pi"))
+      text = wxT("\\pi ");
+    else
+      text = m_text;
+  }
+  else if (m_type == MC_TYPE_LABEL)
+  {
+    text = wxT("\\leqno{\\tt ") + m_text + wxT("}");
+    text.Replace(wxT("%"), wxT("\\%"));
+  }
+  else
+  {
+    text = m_text;
+    text.Replace(wxT("\\"), wxT("\\\\"));
+    text.Replace(wxT("^"), wxT("\\^"));
+    text.Replace(wxT("_"), wxT("\\_"));
+    text.Replace(wxT("%"), wxT("\\%"));
+  }
+  
+  return text + MathCell::ToTeX(all);
+}
+
 wxString TextCell::GetDiffPart()
 {
   return wxT(",") + m_text + wxT(",1");
@@ -299,9 +336,9 @@ void TextCell::Fold(bool fold)
   m_isFolded = fold;
   m_width = -1;
   if (fold)
-    m_text = m_text + wxT(" << Hidden expression. >>");
+    m_text = m_text + wxGetTranslation(g_foldText);
   else
-    m_text = m_text.Left(m_text.Length() - 25);
+    m_text = m_text.Left(m_text.Length() - wxStrlen(wxGetTranslation(g_foldText)));
 }
 
 wxString TextCell::GetSymbolString(CellParser& parser)
@@ -309,6 +346,23 @@ wxString TextCell::GetSymbolString(CellParser& parser)
 #if defined __WXMSW__
   if (m_text == wxT("inf"))
     return wxT("\xA5");
+  else if (m_text == wxT("->"))
+    return wxT("\xAE");
+  else if (m_text == wxT(">="))
+    return wxT("\xB3");
+  else if (m_text == wxT("<="))
+    return wxT("\xA3");
+  else
+    return m_text;
+#elif (wxUSE_UNICODE && WXM_UNICODE_GLYPHS)
+  if (m_text == wxT("inf"))
+    return wxT("\x221E");
+  else if (m_text == wxT("->"))
+    return wxT("\x2192");
+  else if (m_text == wxT(">="))
+    return wxT("\x2265");
+  else if (m_text == wxT("<="))
+    return wxT("\x2264");
   else
     return m_text;
 #else
